@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: lrucache
 version: 1.2.0.0
-id: lrucache-1.2.0.0-97fd799690b7e95999ded6be87e87c88
-key: lruca_LnEKhDbcc8GIMqzAA8165Q
+id: lrucache-1.2.0.0-ceecb0f943a41257c9253e3896a3e896
+key: lruca_30daq1tyUdzK2uuSuaZOMA
 license: BSD3
 copyright: Carl Howells, 2010-2015
 maintainer: chowells79@gmail.com
@@ -26,11 +26,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/lrucache-1.2.0.0
-hs-libraries: HSlrucache-1.2.0.0-LnEKhDbcc8GIMqzAA8165Q
+hs-libraries: HSlrucache-1.2.0.0-30daq1tyUdzK2uuSuaZOMA
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
+    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
 haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
 haddock-html: /usr/share/doc/haskell-lrucache/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
